@@ -92,6 +92,9 @@ INTERNALERROR_NETWORKERR = 'InternalError.NetWorkErr'
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
+# 没有找到对应接口。
+INVALIDPARAMETER_ACTIONNOTFOUND = 'InvalidParameter.ActionNotFound'
+
 # 参数为空。
 INVALIDPARAMETER_EMPTYPARAM = 'InvalidParameter.EmptyParam'
 
@@ -200,6 +203,9 @@ LIMITEXCEEDED_REPLICATIONGROUPLOCKED = 'LimitExceeded.ReplicationGroupLocked'
 # 实例被其它流程锁住。
 RESOURCEINUSE_INSTANCEBEENLOCKED = 'ResourceInUse.InstanceBeenLocked'
 
+# 资源不足。
+RESOURCEINSUFFICIENT = 'ResourceInsufficient'
+
 # uin 值为空。
 RESOURCENOTFOUND_ACCOUNTDOESNOTEXISTS = 'ResourceNotFound.AccountDoesNotExists'
 
